import { type Node } from 'unist';
import webpack from 'webpack';
import { type Options, CodeBlockData } from '../';
/**
 * Creates an object containing the parameters of the current URL.
 *
 * ```js
 * getURLParameters('name=Adam&surname=Smith');
 * // 👉 {name: 'Adam', surname: 'Smith'}
 * ```
 * @param url `name=Adam&surname=Smith`
 * @returns
 */
export declare const getURLParameters: (url: string) => Record<string, string>;
export interface MarkdownDataChild extends Node {
    lang: string;
    meta: string;
    value: string;
    depth?: number;
    children?: Array<MarkdownDataChild>;
}
export interface MarkdownParseData extends MarkdownDataChild {
}
/** 转换 代码*/
export declare const getProcessor: (source: string) => MarkdownDataChild[];
/**
 * ```js
 * 'mdx:preview' => ''  // Empty
 * 'mdx:preview:demo12' => 'demo12' // return meta id => 'demo12'
 * ```
 * @param meta string
 * @returns string?
 */
export declare const getMetaId: (meta?: string) => string;
/**
 * ```js
 * isMeta('mdx:preview') => true
 * isMeta('mdx:preview:demo12') => true
 * isMeta('mdx:preview--demo12') => false
 * ```
 * @param meta
 * @returns boolean
 */
export declare const isMeta: (meta?: string) => boolean;
/** 获取需要渲染的代码块 **/
export declare function getCodeBlock(child: MarkdownParseData['children'], opts?: Options, resourcePath?: string): CodeBlockData['data'];
/**
 * `mdCodeModulesLoader` method for adding `markdown-react-code-preview-loader` to webpack config.
 * @param {webpack.Configuration} config webpack config
 * @param {string[]} lang Parsing language
 * @param {Options} option Loader Options
 * @returns {webpack.Configuration}
 */
export declare const mdCodeModulesLoader: (config: webpack.Configuration, lang?: string[], option?: Options) => webpack.Configuration;
export interface HeadingListType {
    depth: number;
    value: string;
    key: number;
}
export interface HeadingItem extends HeadingListType {
    /**嵌套子标题*/
    children?: HeadingItem[];
}
/**进行获取同级别标题数据*/
export declare const getSameLevelHeading: (list: HeadingListType[]) => HeadingItem[];
/**获取标题*/
export declare const getHeadings: (child: MarkdownParseData["children"]) => {
    headings: HeadingItem[];
    headingsList: HeadingListType[];
};
