"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getCodeBlock = getCodeBlock;
exports.mdCodeModulesLoader = exports.isMeta = exports.getURLParameters = exports.getSameLevelHeading = exports.getProcessor = exports.getMetaId = exports.getHeadings = void 0;
var _toArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toArray"));
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _remark = _interopRequireDefault(require("remark"));
var _transform = require("./transform");
var _ = require("../");
/**
 * Creates an object containing the parameters of the current URL.
 *
 * ```js
 * getURLParameters('name=Adam&surname=Smith');
 * // 👉 {name: 'Adam', surname: 'Smith'}
 * ```
 * @param url `name=Adam&surname=Smith`
 * @returns
 */
var getURLParameters = exports.getURLParameters = function getURLParameters(url) {
  var regex = /([^?=&]+)=([^&]*)/g;
  var params = {};
  var match;
  while (match = regex.exec(url)) {
    params[match[1]] = match[2];
  }
  return params;
};
/** 转换 代码*/
var getProcessor = exports.getProcessor = function getProcessor(source) {
  try {
    // @ts-ignore
    var child = _remark["default"].parse(source);
    return child.children;
  } catch (err) {
    console.warn(err);
  }
};

/**
 * ```js
 * 'mdx:preview' => ''  // Empty
 * 'mdx:preview:demo12' => 'demo12' // return meta id => 'demo12'
 * ```
 * @param meta string
 * @returns string?
 */
var getMetaId = exports.getMetaId = function getMetaId() {
  var meta = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var _ref = /mdx:(.[\w|:]+)/i.exec(meta) || [],
    _ref2 = (0, _slicedToArray2["default"])(_ref, 1),
    _ref2$ = _ref2[0],
    metaRaw = _ref2$ === void 0 ? '' : _ref2$;
  return metaRaw.replace(/^mdx:preview:?/, '');
};

/**
 * ```js
 * isMeta('mdx:preview') => true
 * isMeta('mdx:preview:demo12') => true
 * isMeta('mdx:preview--demo12') => false
 * ```
 * @param meta
 * @returns boolean
 */
var isMeta = exports.isMeta = function isMeta() {
  var meta = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  return meta && meta.includes('mdx:preview');
};

/** 获取需要渲染的代码块 **/
function getCodeBlock(child) {
  var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var resourcePath = arguments.length > 2 ? arguments[2] : undefined;
  var _opts$lang = opts.lang,
    lang = _opts$lang === void 0 ? ['jsx', 'tsx'] : _opts$lang;
  // 获取渲染部分
  var codeBlock = {};
  child.forEach(function (item) {
    if (item && item.type === 'code' && lang.includes(item.lang)) {
      var line = item.position.start.line;
      var metaId = getMetaId(item.meta);
      if (isMeta(item.meta)) {
        var name = metaId || line;
        var funName = "".concat(resourcePath, ".").concat(_.FUNNAME_PREFIX).concat(name);
        var returnCode = (0, _transform.getTransformValue)(item.value, "".concat(funName, ".").concat(item.lang), opts);
        codeBlock[name] = {
          name: name,
          meta: getURLParameters(item.meta),
          code: returnCode,
          language: item.lang,
          value: item.value
        };
      }
    }
  });
  return codeBlock;
}

/**
 * `mdCodeModulesLoader` method for adding `markdown-react-code-preview-loader` to webpack config.
 * @param {webpack.Configuration} config webpack config
 * @param {string[]} lang Parsing language
 * @param {Options} option Loader Options
 * @returns {webpack.Configuration}
 */
var mdCodeModulesLoader = exports.mdCodeModulesLoader = function mdCodeModulesLoader(config, lang) {
  var option = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  config.module.rules.forEach(function (ruleItem) {
    if ((0, _typeof2["default"])(ruleItem) === 'object') {
      if (ruleItem.oneOf) {
        ruleItem.oneOf.unshift({
          test: /.md$/,
          use: [{
            loader: 'markdown-react-code-preview-loader',
            options: (0, _objectSpread2["default"])({
              lang: lang
            }, option)
          }]
        });
      }
    }
  });
  return config;
};
/**进行获取同级别标题数据*/
var _getSameLevelHeading = exports.getSameLevelHeading = function getSameLevelHeading(list) {
  var newList = [];
  var level = 0;
  var satrtIndex = 0;
  var lg = list.length;

  // 对同级别数据进行区分
  for (var index = 0; index < lg; index++) {
    var element = list[index];
    if (index === 0) {
      satrtIndex = 0;
      /**默认第一个数据的层级进行查找*/
      level = element.depth;
    } else if (element.depth === level) {
      // 层级相同则进行赋值
      // 这个位置相等，说明这些数据是一组数据
      newList.push({
        start: satrtIndex,
        end: index
      });
      /**重新赋值开始下标数据*/
      satrtIndex = index;
    }
  }
  // 如果最后位置没找到
  if (satrtIndex <= lg - 1) {
    newList.push({
      start: satrtIndex,
      end: lg
    });
  }
  var saveList = [];

  /**对标题数据进行处理*/
  newList.forEach(function (item) {
    var start = item.start,
      end = item.end;
    var _list$slice = list.slice(start, end),
      _list$slice2 = (0, _toArray2["default"])(_list$slice),
      firstItem = _list$slice2[0],
      lastItems = _list$slice2.slice(1);
    var newItem = (0, _objectSpread2["default"])({}, firstItem);
    if (Array.isArray(lastItems) && lastItems.length) {
      newItem.children = _getSameLevelHeading(lastItems);
    }
    saveList.push(newItem);
  });
  return saveList;
};

/**获取标题*/
var getHeadings = exports.getHeadings = function getHeadings(child) {
  var headingList = [];
  child.forEach(function (item, index) {
    if (item && item.type === 'heading') {
      var depth = item.depth,
        children = item.children;
      if (Array.isArray(children) && children.length) {
        var value = children.map(function (item) {
          return item.value;
        }).join('');
        headingList.push({
          key: index,
          value: value,
          depth: depth
        });
      }
    }
  });
  return {
    headings: _getSameLevelHeading(headingList),
    headingsList: headingList
  };
};